//
//  ViewController.m
//  Base
//
//  Created by NYU User on 8/1/12.
//  Copyright (c) 2012 __MyCompanyName__. All rights reserved.
//

#import "ViewController.h"

/*
This function is called for each record found in the table.
It must be a plain old C function, not an Objective-C method.
The first argument (p) is a pointer to the UITextView.
*/

static int foundRecord(void *p, int argc, char **argv, char **colName) {
	UITextView *textView = (__bridge UITextView *)p;

	//Append each field of the record to the UITextView's text.
	for (int i = 0; i < argc; ++i) {
		//%s for pointer to char
		textView.text = [textView.text stringByAppendingFormat: @"%s ", argv[i]];
	}

	//Append a newline, so that each record will be on a separate line.
	textView.text = [textView.text stringByAppendingString: @"\n"];
	return SQLITE_OK;
}

@implementation ViewController

- (id) initWithNibName: (NSString *) nibNameOrNil bundle: (NSBundle *) nibBundleOrNil
{
	self = [super initWithNibName: nibNameOrNil bundle: nibBundleOrNil];
	if (self) {
		// Custom initialization
		NSString *fileName =
			[NSHomeDirectory() stringByAppendingPathComponent: @"Documents/database.db"];
		
		if (sqlite3_open([fileName UTF8String], &database) != SQLITE_OK) {
			NSLog(@"sqlite3_open: %s", sqlite3_errmsg(database));
			return nil;
		}

		char *error;
		if (sqlite3_exec(database, "drop table if exists people;", NULL, NULL, &error) != SQLITE_OK) {
			NSLog(@"sqlite3_exec: %s", error);
			sqlite3_free(error);
			return nil;
		}
		
		const char *const create =
			"create table people (\n"
			"	lastname text,\n"
			"	firstname text,\n"
			"	ss integer\n"
			");";
		
		if (sqlite3_exec(database, create, NULL, NULL, &error) != SQLITE_OK) {
			NSLog(@"sqlite3_exec: %s", error);
			sqlite3_free(error);
			return nil;
		}

		typedef struct {
			char *lastname;
			char *firstname;
			int ss;
		} person_t;

		static const person_t a[] = {
			{"Ali",			"Gamal",	 1},
			{"Bass",		"Drew",		 2},
			{"Basu",		"Piyal",	 3},
			{"Caraballo",	"Zimri",	 4},
			{"Ciano",		"Dominick",	 5},
			{"Compas",		"Jean Michael",	 6},
			{"Fong",		"Matthew A.",	 7},
			{"Giraud", 		"Frederique",	 8},
			{"Grubb",		"Michael Alexander",	 9},
			{"Guglielmo", 	"Lino",		10},
			{"Gupta", 		"Anita",	11},
			{"Haughwout",	"James",	12},
			{"Krieger",		"Rob",		13},
			{"McConnel",	"Nick",		14},
			{"Meretzky",	"Mark",		15},
			{"Nitz",		"Ryan G.",	16},
			{"Nunez",		"Axel",		17},
			{"Poon",		"Ho-Ling",	18},
			{"Prior",		"Julia",	19},
			{"Ristea",		"Dan",		20}
		};
		static const size_t n = sizeof a / sizeof a[0];

		for (size_t i = 0; i < n; ++i) {
			char *const insert = sqlite3_mprintf(
				"insert into people (lastname, firstname, ss) values ('%q', '%q', %d);",
				a[i].lastname, a[i].firstname, a[i].ss
			);
			
			if (insert == NULL) {
				NSLog(@"sqlite3_mprintf failed.");
				return nil;
			}
			
			if (sqlite3_exec(database, insert, NULL, NULL, &error) != SQLITE_OK) {
				NSLog(@"%s", error);
				sqlite3_free(error);
				return nil;
			}
			
			sqlite3_free(insert);
		}
	}
	return self;
}

- (void) didReceiveMemoryWarning
{
	// Releases the view if it doesn't have a superview.
	[super didReceiveMemoryWarning];

	// Release any cached data, images, etc that aren't in use.
}

#pragma mark - View lifecycle

// Create a view hierarchy programmatically, without using a nib.
- (void) loadView
{
	CGRect frame = [UIScreen mainScreen].applicationFrame;
	self.view = [[UITextView alloc] initWithFrame: frame];
	((UITextView *)self.view).editable = NO;
	((UITextView *)self.view).text = @"";

	//Call foundRecord over and over.
	char *error;
	if (sqlite3_exec(database, "select * from people;", foundRecord, (__bridge void *)self.view, &error)
		!= SQLITE_OK) {
		NSLog(@"%@", error);
		sqlite3_free(error);
	}
}

/*
// Implement viewDidLoad to do additional setup after loading the view, typically from a nib.
- (void) viewDidLoad
{
	[super viewDidLoad];
}
*/

- (void) viewDidUnload
{
	[super viewDidUnload];
	// Release any retained subviews of the main view.
	// e.g. self.myOutlet = nil;

	//If the database was opened, close it.
	if (database != NULL && sqlite3_close(database) != SQLITE_OK) {
		NSLog(@"sqlite3_close failed.");
	}
}

- (BOOL) shouldAutorotateToInterfaceOrientation: (UIInterfaceOrientation) interfaceOrientation
{
	// Return YES for supported orientations
	//return (interfaceOrientation == UIInterfaceOrientationPortrait);
	return YES;
}

@end
